"""Módulo con el código para las pruebas
    La función print_lol imprime listas que pueden contener otras listas"""

def print_lol(lista,profundidad = 0):
    """Recorre(recursivamente) listas anidadas imprimiendo cada elemento por separado
    el argumento 'profuncidad' controla el nivel de sangrado con que se muestran los elementos"""
    for elemento in lista:
        if isinstance(elemento,list):
            print_lol(elemento,profundidad+1)
        else:
            for nivel in range(profundidad):
                print("\t",end="")
            print (elemento)
